#!/bin/sh

if [ $# -lt 1 ]; then
	echo "parameterw not enough."
	exit 1
fi

fconfig=${1}
if [ ! -f ${fconfig} ]; then
	echo "not found config file"
	exit 1;
fi

#. /etc/PG.conf

# define Path
RAMDISK=/usr/ramdisk
libsh=${RAMDISK}/app/cloud/common/libsh

# define bin
FLOWEYE=${RAMDISK}/bin/floweye

# load shell script
. ${libsh}/ippool.sh
. ${libsh}/iwanmap.sh
. ${libsh}/iwansvc.sh
. ${libsh}/account.sh
. ${libsh}/wan.sh
. ${libsh}/route.sh
. ${libsh}/sysapp.sh
. ${libsh}/iptable.sh


# exec

err_num=0
index_num=0
while read act tag row 
do
	index_num=$((${index_num} + 1))

	if [ "${tag}" = "sysapp" ]; then
		errmsg="`sysapp_${act} ${row}`"
		if [ "$?" != "0" ]; then
			echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
			err_num=8
		fi

	elif [ "${tag}" = "usernode" ]; then
		errmsg="`usernode_${act} ${row}`"
		if [ "$?" != "0" ]; then
			echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
			err_num=9
		fi

	elif [ "${tag}" = "ippool" ]; then
		errmsg="`ippool_${act} ${row}`"
		if [ "$?" != "0" ]; then
			echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
			err_num=2
	#		exit 2;
		fi
	fi
done < ${fconfig}

index_num=0
while read act tag row 
do
	index_num=$((${index_num} + 1))
	[ "${tag}" != "account" ] && continue

	errmsg="`account_${act} ${row}`"
	if [ "$?" != "0" ]; then
		echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
		err_num=3
#		exit 5;
	fi
done < ${fconfig}


index_num=0
while read act tag row 
do
	index_num=$((${index_num} + 1))
	[ "${tag}" != "iwansvc" ] && continue

	errmsg="`iwansvc_${act} ${row}`"
	if [ "$?" != "0" ]; then
		echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
		err_num=4
#		exit 3;
	fi
done < ${fconfig}


index_num=0
while read act tag row 
do
	index_num=$((${index_num} + 1))
	[ "${tag}" != "iwanmap" ] && continue

	errmsg="`iwanmap_${act} ${row}`"
	if [ "$?" != "0" ]; then
		echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
		err_num=5
#		exit 4;
	fi
done < ${fconfig}


index_num=0
while read act tag row 
do
	index_num=$((${index_num} + 1))

	if [ "${tag}" != "wan" ]; then
		case "${tag}" in
		"natproxy")
			row="${row} type=proxy"
			;;
		"dhcpwan")
			row="${row} type=dhcpwan"
			;;
		"pppoe")
			row="${row} type=pppoeif"
			;;
		"l2tpwan")
			row="${row} type=l2tpwan"
			;;
		"iwan")
			row="${row} type=iwan"
			;;
		*)
			continue
			;;
		esac
		tag=wan
	fi

	errmsg="`wan_${act} ${row}`"
	if [ "$?" != "0" ]; then
		echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
		err_num=6
#		exit 4;
	fi
done < ${fconfig}



index_num=0
while read act tag row 
do
	index_num=$((${index_num} + 1))
	if [ "${tag}" = "rtp" ]; then
		case "${act}" in
			"del")
				act=remove
			;;
			"lst")
				act=list
			;;
			*)
			;;
		esac
		errmsg="`${FLOWEYE} route ${act} ${row}`"
	elif [ "${tag}" = "route" ]; then
		errmsg="`route_${act} ${row}`"
	else
		continue
	fi

	if [ "$?" != "0" ]; then
		echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
		err_num=7
#		exit 4;
	fi
done < ${fconfig}


index_num=0
while read act tag row 
do
	index_num=$((${index_num} + 1))
	[ "${tag}" != "iptable" ] && continue

	errmsg="`iptable_${act} ${row}`"
	if [ "$?" != "0" ]; then
		echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
		err_num=3
#		exit 5;
	fi
done < ${fconfig}


index_num=0
while read act tag row 
do
	index_num=$((${index_num} + 1))
	[ "${tag}" != "iprng" ] && continue

	errmsg="`iprng_${act} ${row}`"
	if [ "$?" != "0" ]; then
		echo "fail: row=${index_num} tag=${tag} act=${act} msg: ${errmsg}"
		err_num=3
#		exit 5;
	fi
done < ${fconfig}


exit ${err_num}

