#!/bin/sh

iwansvc_add()
{
	local name
	local ifname
	local addr
	local mtu
	local auth
	local pool
	local radsvr
	

	for val in `echo $*`
	do
		eval "${val}"
	done

	: ${auth:=local}
	: ${mtu:=1460}
	: ${pool:=0}
	: ${radsvr:=0}
	: ${addr:='0.0.0.0'}

	if [ "${pool_name}" != "" ]; then
		# id name start end ipleft nextip acctcnt ratein rateout dns0 dns1 maxonlinetime clntepa ifname vlan others
		pool="`${FLOWEYE} pppoeippool list | awk -v n="${pool_name}" '{if(n==$2){printf $1;exit;}}'`"
	fi

	cmdargs="name=${name} ifname=${ifname} addr=${addr} mtu=${mtu}"
	cmdargs="${cmdargs} auth=${auth} pool=${pool}"
	cmdargs="${cmdargs} radsvr=${radsvr}"

	${FLOWEYE} nat addiwansvc ${cmdargs}
}

iwansvc_set()
{
	local name
	local oldname
	local ifname
	local addr
	local mtu
	local auth
	local radsvr
	local pool
	

	for val in `echo $*`
	do
		eval "${val}"
	done
	
	: ${oldname:=${name}}
	: ${auth:=local}
	: ${mtu:=1460}
	: ${radsvr:=0}
	: ${addr:='0.0.0.0'}

	if [ "${pool_name}" != "" ]; then
		# id name start end ipleft nextip acctcnt ratein rateout dns0 dns1 maxonlinetime clntepa ifname vlan others
		pool="`${FLOWEYE} pppoeippool list | awk -v n="${pool_name}" '{if(n==$2){printf $1;exit;}}'`"
	fi
	
	cmdargs="name=${name}"
	[ "${oldname}" != "${name}" ] && cmdargs="newname=${name} name=${oldname}"
	cmdargs="${cmdargs} ifname=${ifname}"
	cmdargs="${cmdargs} addr=${addr} mtu=${mtu}"
	cmdargs="${cmdargs} auth=${auth} radsvr=${radsvr} pool=${pool}"

	${FLOWEYE} nat setiwansvc ${cmdargs}
}


iwansvc_del()
{
	local name

	for val in `echo $*`
	do
		eval "${val}"
	done

	if [ "${name}" = "" ]; then
		echo "INV_SERVER"
		return 1
	fi

	${FLOWEYE} nat rmvproxy ${name}
}


iwansvc_enable()
{
	local id

	for val in `echo $*`
	do
		eval "${val}"
	done

	if [ "${iwansvc_name}" != "" ]; then
		id="`${FLOWEYE} nat getproxy ${iwansvc_name} | grep ^proxyid=`"
		[ "${id}" != "" ] && id="${id#*=}"
	fi

	if [ "${id}" = "" ]; then
		echo "INV_SERVERID"
		return 1
	fi

	${FLOWEYE} nat config enableproxy=${id}
}


iwansvc_disable()
{
	local id

	for val in `echo $*`
	do
		eval "${val}"
	done

	if [ "${iwansvc_name}" != "" ]; then
		id="`${FLOWEYE} nat getproxy ${iwansvc_name} | grep ^proxyid=`"
		[ "${id}" != "" ] && id="${id#*=}"
	fi
	
	if [ "${id}" = "" ]; then
		echo "INV_SERVERID"
		return 1
	fi

	${FLOWEYE} nat config disableproxy=${id}
}



