#!/bin/sh


route_add()
{
	local id
	local inif
	local srctype
	local src
	local srcip
	local srcipnet
	local srciprng
	local srciptbl
	local srcport
	local dsttype
	local dst
	local dstip
	local dstipnet
	local dstiprng
	local dstiptbl
	local dstport
	local dscp
	local proto
	local appid
	local action
	local proxy
	local nexthop
	local vlan
	local schtime
	local ttl
	local usrtype
	local pool
	local desc
	

	for val in `echo $*`
	do
		eval "${val}"
	done

	: ${proto:='any'}

	cmdargs="id=${id}"
	[ "${inif}" != "any" ] && cmdargs="${cmdargs} inif=${inif}"

	if [ "${src}" = "" ]; then
		case "${srctype}" in
			"any")
				srcip="any"
				;;
			"net")
				srcip="${srcipnet}"
				;;
			"range")
				srcip="${srciprng}"
				;;
			"table")
				srcip="${srciptbl}"
				;;
		esac
		if [ "${srcport}" != "" -a "${srcport}" != "0" ]; then
			srcip="${srcip}:${srcport}"
		fi
	else
		srcip="${src}"
	fi
	: ${srcip:='any'}
	cmdargs="${cmdargs} src=${srcip}"
	
	if [ "${dst}" = "" ]; then
		case "${dsttype}" in
			"any")
				dstip="any"
			;;
			"net")
				dstip="${dstipnet}"
			;;
			"range")
				dstip="${dstiprng}"
			;;
			"table")
				dstip="${dstiptbl}"
			;;
		esac
		if [ "${dstport}" != "" -a "${dstport}" != "0" ]; then
			dstip="${dstip}:${dstport}"
		fi
	else
		dstip="${dst}"
	fi
	: ${dstip:='any'}
	cmdargs="${cmdargs} dst=${dstip}"

	if [ "${dscp}" != "" -a "${dscp}" != "0" ]; then
		cmdargs="${cmdargs} dscp=${dscp}"
	fi

	[ "${proto}" != "any" ] && cmdargs="${cmdargs} proto=${proto}"
	[ "${appid}" != "" ] && cmdargs="${cmdargs} app=${appid}"
	if [ "${action}" = "nat" ]; then
		: ${nexthop:='_NULL_'}
		cmdargs="${cmdargs} action=nat-${proxy}"
		cmdargs="${cmdargs} nexthop=${nexthop}"
	elif [ "${action}" = "ippxy" ]; then
		cmdargs="${cmdargs} action=ippxy"
	else
		cmdargs="${cmdargs} action=route-${proxy}"
		: ${nexthop:='0.0.0.0'}
		cmdargs="${cmdargs} nexthop=${nexthop}"
	fi
	if [ "${vlan}" != "" -a "${vlan}" != "0" -a "${vlan}" != "0-0" ]; then
		cmdargs="${cmdargs} vlan=${vlan}"
	fi
	if [ "${schtime}" != "" -a "${schtime}" != "0" ]; then
		cmdargs="${cmdargs} schtime=${schtime}"
	fi
	[ "${ttl}" != "" ] && cmdargs="${cmdargs} ttl=${ttl}"
	[ "${usrtype}" != "any" -a "${usrtype}" != "" ] && cmdargs="${cmdargs} usrtype=${usrtype}"
	[ "${pool}" != "0" -a "${pool}" != "" ] && cmdargs="${cmdargs} pool=${pool}"
	if [ "${desc}" = "" ]; then
		cmdargs="${cmdargs} desc=NULL"
	else
		cmdargs="${cmdargs} desc=${desc}"
	fi

	${FLOWEYE} route add ${cmdargs}
}

route_set()
{
	local id
	local oldid
	local inif
	local srctype
	local src
	local srcip
	local srcipnet
	local srciprng
	local srciptbl
	local srcport
	local dsttype
	local dst
	local dstip
	local dstipnet
	local dstiprng
	local dstiptbl
	local dstport
	local dscp
	local proto
	local appid
	local action
	local proxy
	local nexthop
	local vlan
	local schtime
	local ttl
	local usrtype
	local pool
	local desc


	for val in `echo $*`
	do
		eval "${val}"
	done
	
	: ${oldid:=${id}}
	: ${proto:='any'}

	cmdargs="id=${id}"
	[ "${oldid}" != "${id}" ] && cmdargs="${cmdargs} id=${oldid} newid=${id}"
	[ "${inif}" != "" -a "${inif}" != "any" ] && cmdargs="${cmdargs} inif=${inif}"

	if [ "${src}" = "" ]; then
		case "${srctype}" in
			"any")
				srcip="any"
				;;
			"net")
				srcip="${srcipnet}"
				;;
			"range")
				srcip="${srciprng}"
				;;
			"table")
				srcip="${srciptbl}"
				;;
		esac
		if [ "${srcport}" != "" -a "${srcport}" != "0" ]; then
			srcip="${srcip}:${srcport}"
		fi
	else
		srcip="${src}"
	fi
	: ${srcip:='any'}
	cmdargs="${cmdargs} src=${srcip}"
	
	if [ "${dst}" = "" ]; then
		case "${dsttype}" in
			"any")
				dstip="any"
			;;
			"net")
				dstip="${dstipnet}"
			;;
			"range")
				dstip="${dstiprng}"
			;;
			"table")
				dstip="${dstiptbl}"
			;;
		esac
		if [ "${dstport}" != "" -a "${dstport}" != "0" ]; then
			dstip="${dstip}:${dstport}"
		fi
	else
		dstip="${dst}"
	fi
	: ${dstip:='any'}
	cmdargs="${cmdargs} dst=${dstip}"
	
	if [ "${dscp}" != "" -a "${dscp}" != "0" ]; then
		cmdargs="${cmdargs} dscp=${dscp}"
	fi
	[ "${proto}" != "any" ] && cmdargs="${cmdargs} proto=${proto}"
	[ "${appid}" != "" ] && cmdargs="${cmdargs} app=${appid}"
	if [ "${action}" != "" ]; then
		if [ "${action}" = "nat" ]; then
			cmdargs="${cmdargs} action=nat-${proxy}"
			: ${nexthop:='_NULL_'}
			cmdargs="${cmdargs} nexthop=${nexthop}"
		elif [ "${action}" = "ippxy" ]; then
			cmdargs="${cmdargs} action=ippxy"
		else
			cmdargs="${cmdargs} action=route-${proxy}"
			: ${nexthop:='0.0.0.0'}
			cmdargs="${cmdargs} nexthop=${nexthop}"
		fi
	fi

	if [ "${vlan}" != "" -a "${vlan}" != "0" -a "${vlan}" != "0-0" ]; then
		cmdargs="${cmdargs} vlan=${vlan}"
	fi
	if [ "${schtime}" != "" -a "${schtime}" != "0" ]; then
		cmdargs="${cmdargs} schtime=${schtime}"
	fi

	[ "${ttl}" != "" ] && cmdargs="${cmdargs} ttl=${ttl}"
	[ "${usrtype}" != "any" -a "${usrtype}" != "" ] && cmdargs="${cmdargs} usrtype=${usrtype}"
	[ "${pool}" != "0" -a "${pool}" != "" ] && cmdargs="${cmdargs} pool=${pool}"
	if [ "${desc}" = "" ]; then
		cmdargs="${cmdargs} desc=NULL"
	else
		cmdargs="${cmdargs} desc=${desc}"
	fi

	${FLOWEYE} route set ${cmdargs}
}

route_del()
{
	${FLOWEYE} route remove $*
}

route_enable()
{
	${FLOWEYE} route enable $*
}

route_disable()
{
	${FLOWEYE} route disable $*
}

route_get()
{
	${FLOWEYE} route get $*
}

route_lst()
{
	${FLOWEYE} route list
}




