#!/bin/sh

wan_add()
{
	local name
	local ifname
	local addr
	local gateway
	local dns
	local mtu
	local type
	local clonemac
	local pingip
	local pingip2
	local vlan
	local vlan1
	local natip
	local gwpxy
	local acname
	local svcname
	local waitime
	local svraddr
	local svrport
	local username
	local password
	local ping_disable
	local pingip
	local pingip2
	
	
	for val in `echo $*`
	do
		eval "${val}"
	done

	if [ "${mtu}" = "" -o "${mtu}" = "0" ]; then
		case "${type}" in
		"proxy"|"dhcpwan")
			mtu=1500
			;;
		"pppoe")
			mtu=1460
			;;
		"l2tpwan")
			mtu=1420
			;;
		"iwan")
			mtu=1420
			;;
		*)
			mtu=1500
			;;
		esac
	fi

	: ${clonemac:=00:00:00:00:00:00}
	: ${pingip:=0.0.0.0}
	: ${pingip2:=0.0.0.0}
	: ${vlan:=0}
	: ${vlan1=0}

	cmdargs="name=${name} ifname=${ifname} mtu=${mtu}"
	case "${type}" in
		"proxy")
			natcmd="nat addproxy ${cmdargs}"
			natcmd="${natcmd} addr=${addr} gateway=${gateway}"
			natcmd="${natcmd} dns=${dns} vlan=${vlan} vlan1=${vlan1}"
			natcmd="${natcmd} clonemac=${clonemac}"
			[ "${natip}" = "" ] && natip="0.0.0.0"
			natcmd="${natcmd} natip=${natip}"
			: ${gwpxy:=0}
			natcmd="${natcmd} gwpxy=${gwpxy}"
		;;
		"pppoe")
			natcmd="nat addpppoe ${cmdargs}"
			natcmd="${natcmd} username=${username} password=${password}"
			natcmd="${natcmd} vlan=${vlan} vlan1=${vlan1}"
			natcmd="${natcmd} clonemac=${clonemac}"
			if [ "${CGI_acname}" = "" ]; then
				natcmd="${natcmd} acname=NULL"
			else
				natcmd="${natcmd} acname=${acname}"
			fi
			if [ "${svcname}" = "" ]; then
				natcmd="${natcmd} svcname=NULL"
			else
				natcmd="${natcmd} svcname=${svcname}"
			fi
			[ "${waitime}" = "" -o "${waitime}" = "0" ] && waitime=5
			natcmd="${natcmd} waitime=${waitime}"
		;;
		"l2tpwan")
			[ "${svrport}" = "" ] && svrport="1701"
			natcmd="nat addl2tpwan ${cmdargs} svraddr=${svraddr} svrport=${svrport}"
			natcmd="${natcmd} username=${username} password=${password}"
			[ "${waitime}" = "" -o "${waitime}" = "0" ] && waitime=5
			natcmd="${natcmd} waitime=${waitime}"
		;;
		"iwan")
			[ "${svrport}" = "" -o "${svrport}" = "0" ] && svrport="8000"
			natcmd="nat addiwan ${cmdargs} svraddr=${svraddr} svrport=${svrport}"
			natcmd="${natcmd} username=${username} password=${password}"
		;;
		"dhcpwan")
			natcmd="nat addhcpwan ${cmdargs} vlan=${vlan} vlan1=${vlan1}"
			natcmd="${natcmd} clonemac=${clonemac}"
		;;
		*)
			echo "err type=${type}"
			exit 1
		;;
	esac

	if [ "${ping_disable}" = "1" ]; then
		ping_disable=0
	else
		ping_disable=1
	fi
	natcmd="${natcmd} ping_disable=${ping_disable}"
	natcmd="${natcmd} pingip=${pingip} pingip2=${pingip2}"

	${FLOWEYE} ${natcmd}
}

wan_set()
{
	local name
	local oldname
	local ifname
	local addr
	local gateway
	local dns
	local mtu
	local type
	local clonemac
	local pingip
	local pingip2
	local vlan
	local vlan1
	local natip
	local gwpxy
	local acname
	local svcname
	local waitime
	local svraddr
	local svrport
	local username
	local password
	local ping_disable
	local pingip
	local pingip2
	
	
	for val in `echo $*`
	do
		eval "${val}"
	done

	if [ "${mtu}" = "" -o "${mtu}" = "0" ]; then
		case "${type}" in
		"proxy"|"dhcpwan")
			mtu=1500
			;;
		"pppoe")
			mtu=1460
			;;
		"l2tpwan")
			mtu=1420
			;;
		"iwan")
			mtu=1420
			;;
		*)
			mtu=1500
			;;
		esac
	fi

	: ${oldname:=${name}}
	: ${clonemac:=00:00:00:00:00:00}
	: ${pingip:=0.0.0.0}
	: ${pingip2:=0.0.0.0}
	: ${vlan:=0}
	: ${vlan1=0}


	if [ "${name}" != "${oldname}" ]; then
		cmdargs="name=${oldname} newname=${name}"
	else
		cmdargs="name=${name}"
	fi

	cmdargs="${cmdargs} ifname=${ifname} mtu=${mtu}"
	case "${type}" in
		"proxy")
			natcmd="nat setproxy ${cmdargs}"
			natcmd="${natcmd} addr=${addr} gateway=${gateway}"
			natcmd="${natcmd} dns=${dns} vlan=${vlan} vlan1=${vlan1}"
			natcmd="${natcmd} clonemac=${clonemac}"
			[ "${natip}" = "" ] && natip="0.0.0.0"
			natcmd="${natcmd} natip=${natip}"
			: ${gwpxy:=0}
			natcmd="${natcmd} gwpxy=${gwpxy}"
		;;
		"pppoe")
			natcmd="nat setpppoe ${cmdargs}"
			natcmd="${natcmd} username=${username} password=${password}"
			natcmd="${natcmd} vlan=${vlan} vlan1=${vlan1}"
			natcmd="${natcmd} clonemac=${clonemac}"
			if [ "${CGI_acname}" = "" ]; then
				natcmd="${natcmd} acname=NULL"
			else
				natcmd="${natcmd} acname=${acname}"
			fi
			if [ "${svcname}" = "" ]; then
				natcmd="${natcmd} svcname=NULL"
			else
				natcmd="${natcmd} svcname=${svcname}"
			fi
			[ "${waitime}" = "" -o "${waitime}" = "0" ] && waitime=5
			natcmd="${natcmd} waitime=${waitime}"
		;;
		"l2tpwan")
			[ "${svrport}" = "" ] && svrport="1701"
			natcmd="nat setl2tpwan ${cmdargs} svraddr=${svraddr} svrport=${svrport}"
			natcmd="${natcmd} username=${username} password=${password}"
			[ "${waitime}" = "" -o "${waitime}" = "0" ] && waitime=5
			natcmd="${natcmd} waitime=${waitime}"
		;;
		"iwan")
			[ "${svrport}" = "" -o "${svrport}" = "0" ] && svrport="8000"
			natcmd="nat setiwan ${cmdargs} svraddr=${svraddr} svrport=${svrport}"
			natcmd="${natcmd} username=${username} password=${password}"
		;;
		"dhcpwan")
			natcmd="nat sethcpwan ${cmdargs} vlan=${vlan} vlan1=${vlan1}"
			natcmd="${natcmd} clonemac=${clonemac}"
		;;
		*)
			echo "err type=${type}"
			exit 1
		;;
	esac

	if [ "${ping_disable}" = "1" ]; then
		ping_disable=0
	else
		ping_disable=1
	fi
	natcmd="${natcmd} ping_disable=${ping_disable}"
	natcmd="${natcmd} pingip=${pingip} pingip2=${pingip2}"

	${FLOWEYE} ${natcmd}
}

wan_del()
{
	local name
	
	for val in `echo $*`
	do
		eval "${val}"
	done

	${FLOWEYE} nat rmvproxy ${name}
}

wan_lst()
{
	${FLOWEYE} nat listproxy $*
}

wan_get()
{
	local name
	
	for val in `echo $*`
	do
		eval "${val}"
	done

	${FLOWEYE} nat getproxy ${name}
}
